@@ -25,25 +25,26 @@
 
 'errorGen'<-function(finalraster,validation.spdf,validation.data,plot=FALSE,title=""){
   
-  predicted<-extract(finalraster,validation.spdf)
+  predicted<-raster::extract(finalraster,validation.spdf)
   
   mvp<-data.frame(cbind(validation.data,predicted))
-  fit<-lm(mvp[,2]~mvp[,1])
+  fit<-stats::lm(mvp[,2]~mvp[,1])
   r2<-round(summary(fit)$r.squared,2)
   rmse<-round(sqrt(mean((mvp[,1]-mvp[,2])^2,na.rm=TRUE)),2)
   logmse<-round(log(mean((mvp[,1]-mvp[,2])^2,na.rm=TRUE)),2)
   pe<-round(100*mean(mvp[,1]/mvp[,2],na.rm=TRUE),2)
-  stats<-data.frame(c("r2",r2,"rmse", rmse,"pe",pe,"logmse",logmse))
-  names(stats)<-c("validation stats")
+  stats<-data.frame(r2,rmse,pe,logmse)
+  names(stats)<-c("r2","rmse","pe","logmse")
+  #stats<-data.frame(c("r2",r2,"rmse", rmse,"pe",pe,"logmse",logmse))
+  #names(stats)<-c("validation stats")
   
   stats<-list(stats,mvp)
   
-  
   #optional plotting
   if(plot==TRUE){
     plot(mvp[,1],mvp[,2],ylim=range(mvp[,2],na.rm=T),xlim=range(mvp[,1],na.rm=T),ylab="Interpolated",xlab="Measured",main=title)
-    abline(fit,col="red")
-    abline(a=0,b=1)
+    graphics::abline(fit,col="red")
+    graphics::abline(a=0,b=1)
   }
   
   return(stats)
