@@ -8,6 +8,7 @@
 #'@return RasterStack object of path distances
 #'@import raster
 #'@import gdistance
+#'@importFrom utils setTxtProgressBar
 #'@export
 #'@examples
 #'spdf<-data.frame(rnorm(2))
@@ -29,32 +30,43 @@
 
 'pathdistGen'<-function(spdf,costras,range,yearmon="default"){
   
-
-  ipdw.range<-range/res(costras)[1]/2 #this is a per cell distance
+  
+  ipdw.range<-range/raster::res(costras)[1]/2 #this is a per cell distance
+  #print(ipdw.range)
   
   #start interpolation#####
   #calculate conductances hence 1/max(x)
-  trans<-transition(costras,function(x)1/max(x),directions=16)
+  trans<-gdistance::transition(costras,function(x)1/max(x),directions=16)
   i=1
   coord<-spdf[i,]
-  A<-accCost(trans,coord)
+  #print(coord)
+  #print(coordinates(coord))
+  #print(coord@data)
+  A<-gdistance::accCost(trans,coord)
   dist<-hist(A,plot=F)$breaks[2]
   if(dist<ipdw.range){
     dist=ipdw.range    
   }
   
+  pb<-utils::txtProgressBar(max=nrow(spdf),style=3)
+  
     for(i in 1:nrow(spdf)){
       coord<-spdf[i,]
-      A<-accCost(trans,coord)
-      A2<-reclassify(A,c(dist,+Inf,NA,ipdw.range,dist,ipdw.range)) #raster cells are 1 map unit
+      #print(coord)
+      #print(coordinates(coord))
+      #print(coord@data)
+      A<-gdistance::accCost(trans,coord)
+      A2<-raster::reclassify(A,c(dist,+Inf,NA,ipdw.range,dist,ipdw.range)) #raster cells are 1 map unit
       A3<-((ipdw.range/A2)^2)
-      A4<-reclassify(A3,c(-Inf,1,0))
+      A4<-raster::reclassify(A3,c(-Inf,1,0))
+      #print(i)
       #check output with - zoom(A4,breaks=seq(from=0,to=5,by=1),col=rainbow(5))
       #showTmpFiles()
       
-      rf<-writeRaster(A4,filename=file.path(tempdir(),paste(yearmon,"A4ras",i,".grd",sep="")),overwrite=T,NAflag=-99999)
-      #print(paste(round((i/nrow(spdf))*100,1),"% complete"))
+      rf<-raster::writeRaster(A4,filename=file.path(tempdir(),paste(yearmon,"A4ras",i,".grd",sep="")),overwrite=T,NAflag=-99999)
+      setTxtProgressBar(pb,i)      
     }
+  close(pb)
      
   
   #create raster stack
@@ -62,8 +74,8 @@
   raster_data<-raster_data[grep(".grd",raster_data,fixed=T)]
   as.numeric(gsub('.*A4ras([0123456789]*)\\.grd$','\\1',raster_data))->fileNum
   raster_data<-raster_data[order(fileNum)]
-  rstack<-stack(raster_data)
-  rstack<-reclassify(rstack,cbind(-99999,NA))
+  rstack<-raster::stack(raster_data)
+  rstack<-raster::reclassify(rstack,cbind(-99999,NA))
   file.remove(list.files(path=file.path(tempdir()),pattern=paste(yearmon,"A4ras*",sep=""),full.names=T))
   
   return(rstack)
